# Kuorra login

### Introduction

Kuorra is a Web.py Microframework Frontend, use kuorra to create a MVC skeleton for work with Web.py, MySQL and Heroku App.

this template have the next functions

### Functions

+ Script for create a **kuorra_login** DB
  - *users table*
  - *sessions table*
  - *logs table*
  - * **kuorra** user and **kuorra.2018** password*

+ Config one DB conection.

+ Create a **users Controller**.

  - *Index*
  - *View*
  - *Edit*
  - *Delete*
  - *Insert*
  - *config*
  - *printer*
  - *change_pwd*

+ Create a **main Controller**

  - *index*
  - *login*
  - *logout*
  - *config*

+ Create a **logs Controller**
 - *config*
 - *index*
 - *printer*
 - *view*

+ Create a **Logs Model**
 - *get_all_logs*
 - *insert_logs*

+ Create a **users Model**
 - *validate_user*
 - *get_all_users*
 - *get_users*
 - *delete_users*
 - *insert_users*
 - *edit_users*
 - *update_password*

+ Create a **users View**
 - *change_pwd*
 - *delete*
 - *edit*
 - *index*
 - *insert*
 - *master*
 - *printer*
 - *view*

+ Create a **main View**
 - *admin*
 - *guess*
 - *index*
 - *login*
 - *master*

+ Create a **logs View**
 - *index*
 - *master*
 - *printer*
 - *view*
